@@ -52,6 +52,21 @@ fn synchronize_filename(path: &Path) -> Result<PathBuf, WorkflowError> {
         Err(e) if matches!(e, NoteError::InvalidFrontMatterYaml { .. }) => {
             return Err(WorkflowError::InvalidFrontMatterYaml { source: e })
         }
+        Err(e) if matches!(e, NoteError::InvalidStdinYaml { .. }) => {
+            return Err(WorkflowError::InvalidStdinYaml { source: e })
+        }
+        Err(e) if matches!(e, NoteError::InvalidClipboardYaml { .. }) => {
+            return Err(WorkflowError::InvalidClipboardYaml { source: e })
+        }
+        Err(e) if matches!(e, NoteError::SortTagVarInvalidChar { .. }) => {
+            return Err(WorkflowError::SortTagVarInvalidChar { source: e })
+        }
+        Err(e) if matches!(e, NoteError::FileExtNotRegistered { .. }) => {
+            return Err(WorkflowError::FileExtNotRegistered { source: e })
+        }
+        Err(e) if matches!(e, NoteError::NoHyperlinkFound { .. }) => {
+            return Err(WorkflowError::NoHyperlinkFound { source: e })
+        }
         Err(e) => return Err(e.into()),
     };
 
@@ -287,7 +302,12 @@ pub fn run() -> Result<PathBuf, WorkflowError> {
         Err(e) => {
             if (matches!(e, WorkflowError::InvalidFrontMatterYaml { .. })
                 || matches!(e, WorkflowError::MissingFrontMatter { .. })
-                || matches!(e, WorkflowError::MissingFrontMatterField { .. }))
+                || matches!(e, WorkflowError::MissingFrontMatterField { .. })
+                || matches!(e, WorkflowError::InvalidStdinYaml { .. })
+                || matches!(e, WorkflowError::InvalidClipboardYaml { .. })
+                || matches!(e, WorkflowError::SortTagVarInvalidChar { .. })
+                || matches!(e, WorkflowError::FileExtNotRegistered { .. })
+                || matches!(e, WorkflowError::NoHyperlinkFound { .. }))
                 && !ARGS.batch
                 && ARGS.export.is_none()
             {
